/// <reference types="node" />
import User from "./models/user";
import { UserCredentials } from "./auth/user-credentials";
import { ActionAuth } from "./network/network-actions";
import { EventEmitter } from "events";
import Collection from "./collections/collection";
import Message from "./models/message";
import Guild, { GuildMember } from "./models/guild";
import ClientFetch from "./client-fetch";
export declare type Id = string;
/**
 * @extends EventEmitter
 */
export default class Client extends EventEmitter {
    readonly url: string;
    readonly fetch: ClientFetch;
    private users;
    private members;
    private messages;
    private guilds;
    private me?;
    private socket?;
    private token?;
    private username?;
    private loggedIn;
    /**
     * @param {string} url The url of the server
     */
    constructor(url: string);
    private registerInterceptors;
    /**
     * @return {boolean} Whether the socket is open and connected
     */
    readonly connected: boolean;
    getGuilds(): Collection<Guild>;
    setGuilds(guilds: Collection<Guild>): this;
    setGuild(id: Id, guild: Guild): this;
    getUser(id: Id): User | null;
    getUsers(): Collection<User>;
    getAllMembers(): Collection<Collection<GuildMember>>;
    getMembers(guild: Id): Collection<GuildMember> | null;
    getMember(guild: Id, id: Id): GuildMember | null;
    getMessages(): Collection<Message>;
    setMembers(guild: Id, members: Collection<GuildMember>): this;
    /**
     * @return {boolean} Whether the client is logged in
     */
    isLoggedIn(): boolean;
    /**
     * @return {User | undefined}
     */
    getMe(): User | undefined;
    setMe(me: User): this;
    setToken(token: string, loggedIn?: boolean): void;
    addMessage(message: Message): this;
    useInvite(code: string): this;
    /**
     * Create the socket and setup events
     * @return {this}
     */
    connect(): this;
    /**
     * Send data to the currently opened socket
     * @param {*} data The data to send
     * @return {this}
     */
    send(data: any): this;
    /**
     * Login with credentials and request token
     * @param {UserCredentials} credentials
     * @return {this}
     */
    login(credentials: UserCredentials): this;
    /**
     * @param {string} text
     * @return {this}
     */
    message(text: string): this;
    /**
     * @return {ActionAuth}
     */
    getAuth(): ActionAuth;
    /**
     *
     * @param {*} data
     * @return {boolean} Whether the data is valid
     */
    private static validate;
}
