import { UserCredentials } from "..";
import User, { AvatarHash, UserState } from "../models/user";
import Message from "../models/message";
import { Id } from "../client";
import Channel, { ChannelType } from "../models/channels/channel";
import Guild, { GuildMember } from "../models/guild";
export declare enum NetworkPacketType {
    GetToken = 0,
    GetTokenResponse = 1,
    GetMe = 2,
    GetMeResponse = 3,
    Message = 4,
    MessageSend = 5,
    MessageSendResponse = 6,
    AuthResponse = 7,
    CreateAccount = 8,
    CreateAccountResponse = 9,
    CreateGuild = 10,
    CreateGuildResponse = 11,
    UpdateGuild = 12,
    UpdateGuildResponse = 13,
    TransferOwnership = 14,
    TransferOwnershipResponse = 15,
    GetGuild = 16,
    GetGuildResponse = 17,
    CreateChannel = 18,
    CreateChannelResponse = 19,
    GetChannels = 20,
    GetChannelsResponse = 21,
    GetMembers = 22,
    GetMembersResponse = 23,
    GetMember = 24,
    GetMemberResponse = 25,
    UpdateMe = 26,
    UpdateMeResponse = 27,
    DeleteGuild = 28,
    DeleteGuildResponse = 29,
    GetGuilds = 30,
    GetGuildsResponse = 31,
    UseInvite = 32,
    UseInviteResponse = 33,
    GetInvite = 34,
    GetInviteResponse = 35
}
export declare type UserAccessToken = string;
export declare class NetworkAction {
    readonly _type: NetworkPacketType;
    constructor(type: NetworkPacketType);
}
export interface ActionAuth {
    readonly username: string;
    readonly token: UserAccessToken;
}
export declare class AuthAction extends NetworkAction {
    readonly _auth: ActionAuth;
    constructor(type: NetworkPacketType, auth: ActionAuth);
}
export declare enum AuthResponseState {
    OK = 0,
    InvalidToken = 1,
    TokenExpired = 2
}
export interface AuthResponse {
    readonly state: AuthResponseState;
}
export declare enum GetTokenResponseState {
    OK = 0,
    InvalidCredentials = 1,
    AccountDisabled = 2
}
export interface $GetTokenResponse extends NetworkAction {
    readonly state: GetTokenResponseState;
    readonly token?: UserAccessToken;
}
export interface $GetToken extends NetworkAction {
    readonly credentials: UserCredentials;
}
export interface $MessageSend extends AuthAction {
    readonly text: string;
    readonly channel: Id;
}
export declare enum MessageSendResponseState {
    OK = 0,
    Large = 1,
    Blank = 2,
    Other = 3
}
export interface $MessageSendResponse extends NetworkAction {
    readonly state: MessageSendResponseState;
    readonly localMessageId: number;
}
export interface $Message extends NetworkAction {
    readonly message: Message;
}
export interface $GetMe extends AuthAction {
}
export interface $GetMeResponse extends NetworkAction {
    readonly user: User;
}
export interface $CreateAccount extends NetworkAction {
    readonly username: string;
    readonly password: string;
    readonly email: string;
}
export declare enum CreateAccountResponseState {
    OK = 0,
    EmailExists = 1,
    UsernameTaken = 2,
    InvalidPassword = 3
}
export interface $CreateAccountResponse extends NetworkAction {
    readonly state: CreateAccountResponseState;
}
export interface $CreateGuild extends AuthAction {
    readonly name: string;
}
export declare enum CreateGuildResponseState {
    OK = 0,
    InvalidName = 1,
    TooManyGuilds = 2
}
export interface $CreateGuildResponse extends NetworkAction {
    readonly state: CreateGuildResponseState;
}
export declare enum TransferOwnershipResponseState {
    OK = 0,
    DoesNotExist = 1,
    NoPermission = 2,
    NetOwnerNotInGuild = 3
}
export interface $TransferOwnershipResponse extends NetworkAction {
    readonly state: TransferOwnershipResponseState;
}
export interface $TransferOwnership extends AuthAction {
    readonly guild: Id;
    readonly owner: Id;
}
export interface UpdateGuildChanges {
    readonly name?: string;
    readonly icon?: AvatarHash;
}
export declare enum UpdateGuildResponseState {
    OK = 0,
    DoesNotExist = 1,
    NoPermission = 2
}
export interface $UpdateGuildResponse extends NetworkAction {
    readonly state: UpdateGuildResponseState;
}
export interface $UpdateGuild extends AuthAction {
    readonly guild: Id;
    readonly changes: UpdateGuildChanges;
}
export declare enum DeleteGuildResponseState {
    OK = 0,
    DoesNotExist = 1,
    NoPermission = 2,
    CouldNotDelete = 3
}
export interface $DeleteGuildResponse extends NetworkAction {
    readonly state: DeleteGuildResponseState;
}
export interface $DeleteGuild extends AuthAction {
    readonly guild: Id;
}
export declare enum GetGuildResponseState {
    OK = 0,
    DoesNotExist = 1,
    NotInGuild = 2
}
export interface $GetGuildResponse extends NetworkAction {
    readonly state: GetGuildResponseState;
    readonly guild?: Guild;
}
export interface $GetGuild extends AuthAction {
    readonly guild: Id;
}
export declare enum CreateChannelResponseState {
    OK = 0,
    DoesNotExist = 1,
    NoPermission = 2,
    NotInGuild = 3
}
export interface $CreateChannelResponse extends NetworkAction {
    readonly state: CreateChannelResponseState;
}
export interface $CreateChannel extends AuthAction {
    readonly guild: Id;
    readonly name: string;
    readonly type: ChannelType;
}
export declare enum GetChannelsResponseState {
    OK = 0,
    DoesNotExist = 1,
    NotInGuild = 2
}
export interface $GetChannelsResponse extends NetworkAction {
    readonly state: GetChannelsResponseState;
    readonly channels?: Array<Channel>;
}
export interface $GetChannels extends AuthAction {
    readonly guild: Id;
}
export declare enum GetMembersResponseState {
    OK = 0,
    InvalidRange = 1,
    NotInGuild = 2
}
export interface $GetMembersResponse extends NetworkAction {
    readonly state: GetMembersResponseState;
    readonly members?: Array<GuildMember>;
    readonly pivot?: number;
    readonly guild?: Id;
}
export interface $GetMembers extends AuthAction {
    readonly guild: Id;
    readonly pivot: number;
    readonly count: number;
}
export declare enum GetMemberResponseState {
    OK = 0,
    NotInGuild = 1,
    InvalidMember = 2
}
export interface $GetMemberResponse extends NetworkAction {
    readonly state: GetMemberResponseState;
    readonly member?: GuildMember;
}
export interface $GetMember extends AuthAction {
    readonly guild: Id;
    readonly member: Id;
}
export declare enum UpdateMeResponseState {
    OK = 0,
    InvalidChanges = 1
}
export interface $UpdateMeResponse extends NetworkAction {
    readonly state: UpdateMeResponseState;
}
export interface UpdateMeChanges {
    readonly username?: string;
    readonly password?: string;
    readonly state?: UserState;
    readonly status?: string;
}
export interface $UpdateMe extends AuthAction {
    readonly changes: UpdateMeChanges;
}
export interface $GetGuildsResponse extends NetworkAction {
    readonly guilds?: Array<Guild>;
}
export interface $GetGuilds extends AuthAction {
}
export declare enum UseInviteResponseState {
    OK = 0,
    Invalid = 1
}
export interface $UseInviteResponse extends NetworkAction {
    readonly state: UseInviteResponseState;
    readonly guild?: Guild;
}
export interface $UseInvite extends AuthAction {
    readonly code: string;
}
export declare enum GetInviteResponseState {
    OK = 0,
    NoPermission = 1
}
export interface $GetInviteResponse extends NetworkAction {
    readonly state: GetInviteResponseState;
    readonly code?: string;
}
export interface $GetInvite extends AuthAction {
    readonly guild: Id;
}
export declare function getPacketEventName(type: NetworkPacketType): string;
export default NetworkAction;
